@@ -49,6 +49,12 @@ def automaticallyFindOptimalParameters(self, controller, realExecThroughGUI, det
   else:
     configFile = {"nbWells": 1, "noBoutsDetection": 1, "trackingPointSizeDisplay": 4, "validationVideoPlotHeading": 0, "nbAnimalsPerWell": 1, "forceBlobMethodForHeadTracking": 1, "multipleHeadTrackingIterativelyRelaxAreaCriteria": 1, "erodeIter":0, "minArea": 0, "maxArea": 100000000000000, "minAreaBody": 0, "maxAreaBody": 100000000000000, "headSize": 20, "minTailSize": 0, "maxTailSize": 100000000000000, "paramGaussianBlur": 25, "extractBackWhiteBackground": 1, "dilateIter": 0, "thresholdForBlobImg": 254, "findContourPrecision": "CHAIN_APPROX_NONE", "recalculateForegroundImageBasedOnBodyArea": 0, "headingCalculationMethod": "simplyFromPreviousCalculations", "trackTail": 0}
   
+  originalConfigFile = self.configFile
+  paramsToOverwriteFromOriginalConfigFile = ["setBackgroundToImageMedian"]
+  for param in paramsToOverwriteFromOriginalConfigFile:
+    if param in originalConfigFile:
+      configFile[param] = originalConfigFile[param]
+  
   if "firstFrame" in initialConfigFile:
     configFile["firstFrame"] = initialConfigFile["firstFrame"]
   if "lastFrame" in initialConfigFile:
@@ -171,7 +177,7 @@ def automaticallyFindOptimalParameters(self, controller, realExecThroughGUI, det
   
   # # # Overwritting some of the hyperparameters from hyperparameters in the initial configFile
   
-  listOfParametersToOverwrite = ["extractAdvanceZebraParameters", "nbWells", "nbRowsOfWells", "nbWellsPerRows", "minWellDistanceForWellDetection", "wellOutputVideoDiameter", "wellsAreRectangles", "rectangleWellAreaImageThreshold", "rectangleWellErodeDilateKernelSize", "findRectangleWellArea", "rectangularWellsInvertBlackWhite", "noWellDetection", "oneWellManuallyChosenTopLeft", "oneWellManuallyChosenBottomRight", "multipleROIsDefinedDuringExecution"]
+  listOfParametersToOverwrite = ["extractAdvanceZebraParameters", "nbWells", "nbRowsOfWells", "nbWellsPerRows", "minWellDistanceForWellDetection", "wellOutputVideoDiameter", "wellsAreRectangles", "rectangleWellAreaImageThreshold", "rectangleWellErodeDilateKernelSize", "findRectangleWellArea", "rectangularWellsInvertBlackWhite", "noWellDetection", "oneWellManuallyChosenTopLeft", "oneWellManuallyChosenBottomRight", "multipleROIsDefinedDuringExecution", "groupOfMultipleSameSizeAndShapeEquallySpacedWells"]
   for parameter in listOfParametersToOverwrite:
     if parameter in initialConfigFile:
       configFile[parameter] = initialConfigFile[parameter]
@@ -179,7 +185,7 @@ def automaticallyFindOptimalParameters(self, controller, realExecThroughGUI, det
   print("Intermediary config file:", configFile)
     
   # Adjusting config file hyperparameters related to bouts detection
-  if (configFile["nbAnimalsPerWell"] == 1) and detectBouts:
+  if detectBouts:
     configFile = boutDetectionParameters(data, configFile, pathToVideo, videoName, videoExt, wellPositions, videoPath)
   
   # Setting recalculateForegroundImageBasedOnBodyArea to 1 when asked by user to try to obtain better tail tracking
