@@ -132,14 +132,36 @@ class BoutClustering(tk.Frame):
     tk.Label(self, text="Choose number of cluster to find:").pack()
     nbClustersToFind = tk.Entry(self)
     nbClustersToFind.pack()
+    tk.Label(self, text="").pack()
     
     tk.Label(self, text="Choose one of the options below:").pack()
     FreelySwimming = IntVar()
     Checkbutton(self, text="Freely swimming fish with tail tracking", variable=FreelySwimming).pack()
     HeadEmbeded = IntVar()
     Checkbutton(self, text="Head embeded fish with tail tracking", variable=HeadEmbeded).pack()
+    tk.Label(self, text="").pack()
     
-    tk.Button(self, text="Launch Analysis", bg="light yellow", command=lambda: controller.boutClustering(controller, nbClustersToFind.get(), FreelySwimming.get(), HeadEmbeded.get())).pack()
+    tk.Label(self, text="What's the minimum number of bends a bout should have to be taken into account for the analysis?", font=("Helvetica", 10)).pack(side="top", fill="x")
+    tk.Label(self, text="(the default value is 3) (put 0 if you want all bends to be taken into account)", font=("Helvetica", 10)).pack(side="top", fill="x")
+    minNbBendForBoutDetect = tk.Entry(self)
+    minNbBendForBoutDetect.pack()
+    tk.Label(self, text="").pack()
+    
+    tk.Label(self, text="Optional: generate videos containing the most representative bouts for each cluster: enter below the number of bouts for each video:", font=("Helvetica", 10)).pack(side="top", fill="x")
+    tk.Label(self, text="(leave blank if you don't want any such cluster validation videos to be generated)", font=("Helvetica", 10)).pack(side="top", fill="x")
+    nbVideosToSave = tk.Entry(self)
+    nbVideosToSave.pack()
+    tk.Label(self, text="").pack()
+    
+    modelUsedForClustering = IntVar()
+    Checkbutton(self, text="Use GMM clustering method instead of Kmeans (clustering method used by default)", variable=modelUsedForClustering).pack()
+    tk.Label(self, text="")
+    
+    removeOutliers = IntVar()
+    Checkbutton(self, text="Remove outliers before clustering", variable=removeOutliers).pack()
+    tk.Label(self, text="")
+    
+    tk.Button(self, text="Launch Analysis", bg="light yellow", command=lambda: controller.boutClustering(controller, nbClustersToFind.get(), FreelySwimming.get(), HeadEmbeded.get(), minNbBendForBoutDetect.get(), nbVideosToSave.get(), modelUsedForClustering.get(), removeOutliers.get())).pack()
     
     tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()
 
