@@ -1,13 +1,14 @@
 from zebrazoom.code.preprocessImage import preprocessImage
 import numpy as np
 import cv2
+import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
 
 def headEmbededFrameBackExtract(videoPath, background, hyperparameters, frameNumber):
   
   minPixelDiffForBackExtract = hyperparameters["minPixelDiffForBackExtract"]
   debug = 0
   
-  cap = cv2.VideoCapture(videoPath)
+  cap = zzVideoReading.VideoCapture(videoPath)
   
   cap.set(1, frameNumber)
   ret, frame = cap.read()
