@@ -16,31 +16,28 @@ import os
 import shutil
 import time
 import cv2
+import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
 import json
 
 from zebrazoom.code.vars import getGlobalVariables
 globalVariables = getGlobalVariables()
-import multiprocessing as mp
-if globalVariables["mac"]:
-  mp.set_start_method('spawn', force=True)
-from multiprocessing import Process
 
-output = mp.Queue()
+output = 0
 
 # Does the tracking and then the extraction of parameters
-def getParametersForWell(videoPath,background,wellNumber,wellPositions,output,previouslyAcquiredTrackingDataForDebug,hyperparameters, videoName):
+def getParametersForWell(videoPath,background,wellNumber,wellPositions,output,previouslyAcquiredTrackingDataForDebug,hyperparameters, videoName, dlModel):
   if hyperparameters["debugPauseBetweenTrackAndParamExtract"] == "noDebug":
     # Normal execution process
-    trackingData = tracking(videoPath,background,wellNumber,wellPositions,hyperparameters, videoName)
+    trackingData = tracking(videoPath,background,wellNumber,wellPositions,hyperparameters, videoName, dlModel)
     parameters = extractParameters(trackingData, wellNumber, hyperparameters, videoPath, wellPositions, background)
     output.put([wellNumber,parameters,[]])
   elif hyperparameters["debugPauseBetweenTrackAndParamExtract"] == "justSaveTrackData":
     # Extracing tracking data, saving it, and that's it
-    trackingData = tracking(videoPath,background,wellNumber,wellPositions,hyperparameters, videoName)
+    trackingData = tracking(videoPath,background,wellNumber,wellPositions,hyperparameters, videoName, dlModel)
     output.put([wellNumber,[],trackingData])
   elif hyperparameters["debugPauseBetweenTrackAndParamExtract"] == "saveTrackDataAndExtractParam":
     # Extracing tracking data, saving it, and continuing normal execution
-    trackingData = tracking(videoPath,background,wellNumber,wellPositions,hyperparameters, videoName)
+    trackingData = tracking(videoPath,background,wellNumber,wellPositions,hyperparameters, videoName, dlModel)
     parameters = extractParameters(trackingData, wellNumber, hyperparameters, videoPath, wellPositions, background)
     output.put([wellNumber,parameters,trackingData])
   else: # hyperparameters["debugPauseBetweenTrackAndParamExtract"] == "justExtractParamFromPreviousTrackData"
@@ -66,11 +63,29 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
   videoNameWithExt = videoName + '.' + videoExt
   previouslyAcquiredTrackingDataForDebug = []
 
+  # Checking that path and video exists
+  if not(os.path.exists(os.path.join(pathToVideo, videoNameWithExt))):
+    print("Path or video name is incorrect for", os.path.join(pathToVideo, videoNameWithExt))
+    return 0
+
   # Getting hyperparameters
   [hyperparameters, configFile] = getHyperparameters(configFile, videoNameWithExt, os.path.join(pathToVideo, videoNameWithExt), argv)
   
+  if hyperparameters["trackingDL"]:
+    import torch.multiprocessing as mp
+  else:
+    import multiprocessing as mp
+  if globalVariables["mac"] or hyperparameters["trackingDL"]:
+    mp.set_start_method('spawn', force=True)
+  if hyperparameters["trackingDL"]:
+    from torch.multiprocessing import Process
+  else:
+    from multiprocessing import Process
+
+  output = mp.Queue()
+  
   # Checking first frame and last frame value
-  cap   = cv2.VideoCapture(os.path.join(pathToVideo, videoNameWithExt))
+  cap   = zzVideoReading.VideoCapture(os.path.join(pathToVideo, videoNameWithExt))
   nbFrames = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))
   cap.release()
   if hyperparameters["firstFrame"] < 0:
@@ -83,8 +98,9 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
     print("Error: The parameter 'lastFrame' in your configuration file is too small")
     raise NameError("Error: The parameter 'lastFrame' in your configuration file is too small")
   if hyperparameters["lastFrame"] > nbFrames:
-    print("Error: The parameter 'lastFrame' in your configuration file is too big")
-    raise NameError("Error: The parameter 'lastFrame' in your configuration file is too big")
+    print("Warning: The parameter 'lastFrame' in your configuration file is too big so we adjusted it to the value:", nbFrames-2, "it was originally set to", hyperparameters["lastFrame"])
+    hyperparameters["lastFrame"] = nbFrames - 2
+    # raise NameError("Error: The parameter 'lastFrame' in your configuration file is too big")
   
   # Setting output folder
   outputFolderVideo = os.path.join(hyperparameters["outputFolder"], videoName)
@@ -101,7 +117,7 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
     outfile.close()
   else:
     # Creating output folder
-    if not(hyperparameters["reloadWellPositions"]) and not(hyperparameters["reloadBackground"]) and not(os.path.exists(os.path.join(outputFolderVideo, 'intermediaryWellPositionReloadNoMatterWhat.txt'))):
+    if not(hyperparameters["reloadWellPositions"]) and not(hyperparameters["reloadBackground"]) and not(os.path.exists(os.path.join(outputFolderVideo, 'intermediaryWellPositionReloadNoMatterWhat.txt'))) and not(hyperparameters["dontDeleteOutputFolderIfAlreadyExist"]):
       if os.path.exists(outputFolderVideo):
         shutil.rmtree(outputFolderVideo)
       while True:
@@ -154,7 +170,7 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
     raise ValueError
     
   # Getting background
-  if hyperparameters["backgroundSubtractorKNN"] or (hyperparameters["headEmbeded"] and hyperparameters["headEmbededRemoveBack"] == 0 and hyperparameters["headEmbededAutoSet_BackgroundExtractionOption"] == 0 and hyperparameters["adjustHeadEmbededTracking"] == 0):
+  if hyperparameters["backgroundSubtractorKNN"] or (hyperparameters["headEmbeded"] and hyperparameters["headEmbededRemoveBack"] == 0 and hyperparameters["headEmbededAutoSet_BackgroundExtractionOption"] == 0 and hyperparameters["adjustHeadEmbededTracking"] == 0) or hyperparameters["trackingDL"] or hyperparameters["fishTailTrackingDifficultBackground"]:
     background = []
   else:
     print("start get background")
@@ -165,12 +181,20 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
     else:
       outfile = open(os.path.join(outputFolderVideo, 'intermediaryBackground.txt'),'wb')
       background = getBackground(os.path.join(pathToVideo, videoNameWithExt), hyperparameters)
-      pickle.dump(background,outfile)
+      pickle.dump(background, outfile)
+      cv2.imwrite(os.path.join(outputFolderVideo, 'background.png'), background)
     outfile.close()
   if hyperparameters["exitAfterBackgroundExtraction"]:
     print("exitAfterBackgroundExtraction")
     raise ValueError
   
+  # Reloading DL model for tracking with DL
+  if hyperparameters["trackingDL"]:
+    from zebrazoom.code.deepLearningFunctions.loadDLmodel import loadDLmodel
+    dlModel = loadDLmodel(hyperparameters["trackingDL"])
+  else:
+    dlModel = 0
+  
   # Tracking and extraction of parameters
   if hyperparameters["fasterMultiprocessing"] == 1:
     processes = -1
@@ -181,21 +205,21 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
         # for all wells, in parallel
         processes = []
         for wellNumber in range(0,hyperparameters["nbWells"]):
-          p = Process(target=getParametersForWell, args=(os.path.join(pathToVideo, videoNameWithExt), background, wellNumber, wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName))
+          p = Process(target=getParametersForWell, args=(os.path.join(pathToVideo, videoNameWithExt), background, wellNumber, wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName, dlModel))
           p.start()
           processes.append(p)
       else:
         # for just one well
         processes = [1]
-        getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, hyperparameters["onlyTrackThisOneWell"], wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName)
+        getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, hyperparameters["onlyTrackThisOneWell"], wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName, dlModel)
     else:
       if hyperparameters["onlyTrackThisOneWell"] == -1:
         processes = [1 for i in range(0, hyperparameters["nbWells"])]
         for wellNumber in range(0,hyperparameters["nbWells"]):
-          getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, wellNumber, wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName)
+          getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, wellNumber, wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName, dlModel)
       else:
         processes = [1]
-        getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, hyperparameters["onlyTrackThisOneWell"], wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName)
+        getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, hyperparameters["onlyTrackThisOneWell"], wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName, dlModel)
   
   # Sorting wells after the end of the parallelized calls end
   if processes != -1:
@@ -233,7 +257,7 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
         infoFrame = createValidationVideo(os.path.join(pathToVideo, videoNameWithExt), superStruct, hyperparameters)
     
     # Various post-processing options depending on configuration file choices
-    dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoName)
+    dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoName, videoExt)
   
   # Copying output result folder in another folder
   if len(hyperparameters["additionalOutputFolder"]):
